@@ -9,7 +9,7 @@ __all__ = [
 ]
 
 
-def evaluate_confusion_matrix(dataloader, model, device, desc=None):
+def evaluate_confusion_matrix(dataloader, model, device, desc=""):
     model.eval()
     metric = MiniBatchConfusionMatrix()
     for feature, target in tqdm(dataloader, desc=desc.title(), leave=False):
@@ -19,7 +19,7 @@ def evaluate_confusion_matrix(dataloader, model, device, desc=None):
     return metric.compute()
 
 
-def evaluate_accuracy(dataloader, model, device, desc=None):
+def evaluate_accuracy(dataloader, model, device, desc=""):
     model.eval()
     metric = MiniBatchAccuracy()
     for feature, target in tqdm(dataloader, desc=desc.title(), leave=False):
