@@ -612,16 +612,16 @@ snippet = {
                         "import torch",
                         "device = torch.device(\"cuda:0\" if torch.cuda.is_available() else \"cpu\")",
                         "",                             
-                        "model = torch.load(\"model/model_best.pth\", map_location=\"cpu\").to(device)"
+                        "model = torch.load(\"output/model_best.pth\", map_location=\"cpu\").to(device)"
                     ]
                 },{
                     "name": "Load config, metadata, etc",
                     "snippet": [
                         "import torch",
                         "",
-                        "model_config = torch.load(\"model/model_configs.pth\")",
-                        "optimizer_config = torch.load(\"model/optimizer_configs.pth\")",
-                        "metadata = torch.load(\"model/metadata.pth\")"
+                        "model_config = torch.load(\"output/model_configs.pth\")",
+                        "optimizer_config = torch.load(\"output/optimizer_configs.pth\")",
+                        "metadata = torch.load(\"output/metadata.pth\")"
                     ]
                 }
             ]
